# uwudu

your daily todo list manager now on your cli

*(U w U)**** RISE AND GRIND ****(U w U)*

## Installation
### Using Pip

If you use pip, you can install `uwudu` with the following commands:

```shell
pip install uwudu 
```

### Using Homebrew

If you use Homebrew, you can install `uwudu` with the following commands:

```shell
brew tap uwudu/uwudu
brew install uwudu
```

### To add path if showing command not found

For Bash users
```shell
echo 'export PATH=$PATH:$HOME/.local/bin' >> ~/.bashrc
source ~/.bashrc
```

For Zsh users
```shell
echo 'export PATH=$PATH:$HOME/.local/bin' >> ~/.zshrc
source ~/.zshrc
```

